<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
	exit;

class CKav_Pricing extends Widget_Base {

	public function get_name() { 
		return 'ckav-pricing';
	}

	public function get_title() {
		return esc_html__( 'Pricing', 'orb' );
	}
 
	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'ckav-pack' ];
	}

	protected function _register_controls() {
        
		/*
		* Content section 
		*************************/
		$this->start_controls_section(
			'section_tab', [
				'label' =>esc_html__( 'Content section', 'orb' ),
			]
        );

            $this->add_control(
                'columns', [
                    'type' => Controls_Manager::SELECT,
                    'label' => esc_html__('Number of columns', 'orb'),
                    'default' => '3',
                    'options' => [
                        '1' => esc_html__('1', 'orb'),
                        '2' => esc_html__('2', 'orb'),
                        '3' => esc_html__('3', 'orb'),
                        '4' => esc_html__('4', 'orb'),
                    ],
                ]
            );
			
            $this->add_control(
                'price_packs',
                [
                    'label' => '',
                    'type' => Controls_Manager::REPEATER,
                    'default' => [
                        [
                            'title' => esc_html__( 'Price packs', 'orb' ),
                        ],
                    ],
                    'fields' => [
                        [
                            'name' => 'title',
                            'type' => Controls_Manager::TEXT,
                            'label' => esc_html__('Title', 'orb'),
                            'default'   =>  esc_html__('Basic','orb'),
                            'label_block' => true,
                        ],
                        [
                            'name' => 'icon_status',
                            'type' => Controls_Manager::SWITCHER,
                            'label' => esc_html__('Use font icon?', 'orb'),
                            'label_block' => false,
                            'default' => 'yes',
                            'yes' => esc_html__( 'Yes', 'orb' ),
                            'no' => esc_html__( 'No', 'orb' ), 
                        ],
                        [
                            'name' => 'icon',
                            'label' => esc_html__( 'Icon', 'orb' ),
                            'type' => Controls_Manager::ICONS,
                            'default' => [
                                'value' => 'pe-7s-rocket',
                                'library' => 'pixeden-icons'
                            ],
                            'condition' => [
                                'icon_status' => 'yes',
                            ],
                        ],
                        [
                            'name' => 'icon_image',
                            'type' => Controls_Manager::MEDIA,
                            'label' => esc_html__('Icon image', 'orb'),
                            'label_block' => true,
                            'condition' => [
                                'icon_status' => '',
                            ],
                        ],
                        [
                            'name' => 'price_content',
                            'type' => Controls_Manager::TEXTAREA,
                            'label' => esc_html__('Price Content', 'orb'),
                            'default' => esc_html__("Web Development\nAdvertising\nApp Development\nMusic\nWriting\nPhotography", 'orb'),
                            'label_block' => true,
                        ],
                        [
                            'name' => 'price_val',
                            'type' => Controls_Manager::TEXT,
                            'label' => esc_html__('Price value', 'orb'),
                            'default'   =>  esc_html__('$30','orb'),
                            'label_block' => false,
                        ],
                        [
                            'name' => 'plan_duration',
                            'type' => Controls_Manager::TEXT,
                            'label' => esc_html__('Duration text', 'orb'),
                            'default'   => esc_html__('/ Hour', 'orb'),
                            'label_block' => false,
                        ],
                        [
                            'name' => 'btn_text',
                            'type' => Controls_Manager::TEXT,
                            'label' => esc_html__('Button Text', 'orb'),
                            'default'   => esc_html__('Get started', 'orb'),
                            'label_block' => false,
                        ],
                        [
                            'name'          => 'btn_url',
                            'type'          => Controls_Manager::URL,
                            'label'         => esc_html__('Button URL', 'orb'),
                            'placeholder'   => esc_url('http://example.com'),
                            'label_block'   => true,
                        ],
                        [
                            'name' => 'featured',
                            'type' => Controls_Manager::SWITCHER,
                            'label' => esc_html__('Make it featured?', 'orb'),
                            'label_block' => false,
                            'default' => 'no',
                            'yes' => esc_html__( 'Yes', 'orb' ),
                            'no' => esc_html__( 'No', 'orb' ), 
                        ],
                        [
                            'name' => 'label_text',
                            'type' => Controls_Manager::TEXT,
                            'label' => esc_html__('Label Text', 'orb'),
                            'default'   => esc_html__('Popular', 'orb'),
                            'label_block' => false,
                            'condition' => [
                                'featured' => 'yes',
                            ],
                        ],
                        [
                            'name' => 'btn_color',
                            'type' => Controls_Manager::SELECT,
                            'label' => esc_html__('Button color', 'orb'),
                            'default' => 'primary-btn',
                            'options' => [
                                'default-btn' => esc_html__('Default', 'orb'),
                                'primary-btn' => esc_html__('Primary', 'orb'),
                                'dark-btn' => esc_html__('Dark', 'orb'),
                                'white-btn' => esc_html__('White', 'orb'),
                            ],
                        ],

                    ],
                    'title_field' => '{{{ title }}}',
                ]
            );

        $this->end_controls_section();

        /*
		* Settings
		*************************/
		$this->start_controls_section(
			'setting_tab', [
				'label' =>esc_html__( 'Settings', 'orb' ),
			]
		);

			$this->add_control(
				'light_theme', [
					'type' => Controls_Manager::SWITCHER,
					'label' => esc_html__('Apply light theme?', 'orb'),
					'label_block' => false,
					'default' => 'no',
					'yes' => esc_html__( 'Yes', 'orb' ),
					'no' => esc_html__( 'No', 'orb' ), 
				]
            );

            $this->add_control(
				'icon_color', [
					'label'		 =>esc_html__( 'Icon color', 'orb' ),
					'type'		 => Controls_Manager::COLOR,
					'selectors'	 => [
						'{{WRAPPER}} .iconbox' => 'color: {{VALUE}};',
					],
				]
            );
            
            $this->add_control(
				'poptag_color', [
					'label'		 =>esc_html__( 'Popular tag color', 'orb' ),
                    'type'		 => Controls_Manager::COLOR,
                    'selectors'	 => [
                        '{{WRAPPER}} .pop-label' => 'background-color: {{VALUE}};',
                        '{{WRAPPER}} .pop-label::after' => 'border-top-color: {{VALUE}};',
                    ],
                    'separator' => 'before',
				]
            );
            $this->add_control(
				'poptagtxt_color', [
					'label'		 =>esc_html__( 'Popular tag text', 'orb' ),
					'type'		 => Controls_Manager::COLOR,
					'selectors'	 => [
                        '{{WRAPPER}} .pop-label' => 'color: {{VALUE}};',
					],
				]
			);

            
		$this->end_controls_section();

	}

	protected function render() {
		
		$settings = $this->get_settings_for_display();
		
		require THEME_ELE . '/templates/pricing/style1.php';
	}

	protected function _content_template() { }
}
