<?php
/**
 * The Template for displaying all single posts
 *
 * @link http://codex.wordpress.org/Template_Hierarchy
 */

get_header(); ?>

<?php if ( have_posts() ) : while(have_posts()) : the_post(); 
	$header_h = has_post_thumbnail(get_the_ID()) ? 'vh70' : '';
?>

	<!-- Main header
	******************************-->
	<header class="section typo-light single-post-header <?php echo esc_attr($header_h); ?>">
		<div class="container">

			<div class="row">
				<?php if (is_sticky()) { ?>
				<div class="col-auto stikly-post-tag">
					<i class="fas fa-bookmark"></i>
				</div>
				<?php } ?>

				<div class="col-md">
					<?php if( count( wp_get_post_tags( get_the_ID() ) ) > 0 ) : ?>
					<div class="post-tags">
						<?php foreach( get_the_tags( get_the_ID() ) as $tag ) :
						$term_link = get_tag_link( $tag->term_id ); ?>
						<a href="<?php echo esc_url( $term_link ); ?>" class="ckav-btn tag-btn light">
							<?php echo esc_attr( $tag->name ); ?>
						</a>
						<?php endforeach; ?>
						
					</div>
					<?php endif; ?>
					
					<h1 class="page-title"><?php echo get_the_title(); ?></h1>

					<?php if( is_singular( 'post' ) ) : ?>
					<ul class="row ckav-post-meta gt0">
						<li class="col-auto"><?php ckav_post_meta('author'); ?></li>

						<?php if (ckav_theme_option( "customizer", "blog-dateformat") === "yes" ) { ?>
						<li class="col-auto"><?php ckav_post_meta('date'); ?></li>
						<?php } else { ?>
						<li class="col-auto"><p><?php echo get_the_date(); ?></p></li>
						<?php } ?>
						
						<li class="col-auto"><?php ckav_post_meta('category'); ?></li>
					</ul>
					<?php endif; ?>

				</div>

			</div>
			
		</div>

		<div class="full-wh bg-cc bg-cover" data-bg="<?php echo get_the_post_thumbnail_url(); ?>">
			<b class="full-wh z1" style="background: linear-gradient(to bottom, rgba(0,0,0,0.1) 50%, rgba(0,0,0,0.8) 100%);"></b>
		</div>
	</header>


	<!-- Article
	******************************-->
	<section class="section single-post-content">
		<div class="container">
			<article id="post-<?php the_ID(); ?>" <?php post_class( 'single-post-article' ); ?>>
				<?php 
					the_content(); 
					ckav_pagelinks();
				?>
			</article>
			
			<!-- Author
			******************************-->
			<?php if( get_the_author_meta( 'description' ) ) : ?>
			<div class="info-obj ico-large img-l g30 post-author">
				<div class="img"><?php echo get_avatar( get_the_author_meta( 'ID' ), '185' ); ?></div>
				<div class="info">
					<h4 class="content-title txt-upper"><?php the_author(); ?></h4>
					<p><?php the_author_meta( 'description' ); ?></p>
				</div>
			</div><!-- info box -->
			<?php endif; ?>
		</div>
	</section>
	
	<?php 
	/* Post navigation
	/******************************/
	$prev_post = get_previous_post();
	$next_post = get_next_post();
	if (isset($prev_post->ID) || isset($next_post->ID)) {
	?>
	<div class="post-pagination light-bg">
		<div class="container">
			<div class="row">
				<div class="col-md-6 prev">
					<?php if( isset($prev_post->ID) && get_permalink($prev_post->ID) ) { ?>
					<p class="italic mr-0"><?php echo esc_html__('Previous' , 'orb') ?></p>
					<h4 class="content-title large mr-0"><a href="<?php echo esc_url( get_permalink($prev_post->ID) ); ?>"><i class="fas fa-long-arrow-alt-left fs20 align-m mr-r-4"></i> <span><?php echo esc_html($prev_post->post_title) ?></span></a></h4>
					<?php } ?>
				</div>

				<?php if( isset($next_post->ID) && get_permalink($next_post->ID) ) { ?>
				<div class="next col-md-6">
					<p class="italic mr-0"><?php echo esc_html__('Next' , 'orb') ?></p>
					<h4 class="content-title large mr-0"><a href="<?php echo esc_url( get_permalink($next_post->ID) ); ?>"><span><?php echo esc_html($next_post->post_title) ?></span> <i class="fas fa-long-arrow-alt-right fs20 align-m mr-l-4"></i></a></h4>
				</div>
				<?php } ?>

			</div>
		</div>
	</div>
	<?php } else { ?>
	<hr class="mr-0">
	<?php } ?>
	
	<?php 
	// If comments are open or we have at least one comment, load up the comment template.
	if ( comments_open() || get_comments_number() ) :?>
	<section class="section">
		<div class="container">
			<?php comments_template(); ?>
		</div>
	</section>
	<?php endif; ?>
	
<?php endwhile;  endif;

get_footer();

